##  Applying Inventory Updates
To apply updates, switch to the editor. There, you can click the Updates button to view all updates available for the diagram. Select the updates that you want to apply and click Apply Updates.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f21347a4410149722aabc06221f1d_LowRes.gif)
Toggling on the Auto update view colors and labels removes from the modal all updates related to updating fact sheet view colors and labels. This setting is enabled by default on new diagrams but can be turned off and on as needed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fe56b7a4410148489b7a931538777_LowRes.png)
**Note**
The diagrams can be exported to other formats such as PDF, SVG, PNG, HTML embed code, and XML file, which is compatible with draw.io. Check the documentation on Exporting diagrams for more details.
YesNo
Send
